@@ -20,6 +20,7 @@ Entry_Handler::print_entries (char *class_name)
 #else
   char *buffer = new char[width];
 #endif
+  int row;
 
   /* Print out the file class name, nicely centered and in inverse video. */
   sprintf (buffer, "[ %d %s File%s ]", entries, class_name, entries == 1 ? "" : "s");
@@ -31,7 +32,7 @@ Entry_Handler::print_entries (char *class_name)
 
   /* Take care of everything but the (possibly non-existent) final row. */
   
-  for (int row = 0; row < nrows - 1; row++)
+  for (row = 0; row < nrows - 1; row++)
     {
       /* This loop is subtle, since we don't want to process too many entries.... */
       
