@@ -1,11 +1,11 @@
 /* Handles screen manipulations for screen width and inverse mode. */
 #include "screen.h"
 
+#if !defined(hpux) && !defined(__linux__) && !defined(_AIX41)
 extern "C" int tgetent(void *, const char *);
 extern "C" int tgetnum(const char*);
 extern "C" char *tgetstr(const char *, char**);
-typedef int (*int_func)(int);
-extern "C" void tputs(char *, int, int_func);
+#endif
 
 /* Initializes the current screen width via
    the terminal independent operation routines. */
@@ -34,11 +34,6 @@ Screen_Handler::Screen_Handler (void)
 }
 
 
-static int fputchar (int i)
-{
-  return putchar (i);
-}
-
 /* Prints out leading blanks so as to center buf 
    assuming a screen width of width. */
 
@@ -61,7 +56,6 @@ Screen_Handler::print_inverse_centered (char *buf)
 {
   putchar ('\n');
   center (buf);
-  tputs (inverse_start, 1, fputchar);
-  printf ("%s\n\n", buf);
-  tputs (inverse_end, 1, fputchar);
+  /* Should use tputs, but some systems have a bad prototype for it. */
+  printf ("%s%s%s\n\n", inverse_start,  buf, inverse_end);
 }
