@@ -15,8 +15,8 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with GNU GPERF; see the file COPYING.  If not, write to
-the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
+along with GNU GPERF; see the file COPYING.  If not, write to the Free
+Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111, USA.  */
 
 /* AIX requires the alloca decl to be the first thing in the file. */
 #ifdef __GNUC__
@@ -164,6 +164,7 @@ Key_List::get_array_type (void)
    of characters not from REJECT (borrowed from Henry Spencer's
    ANSI string package, when GNU libc comes out I'll replace this...). */
 
+#ifndef strcspn
 inline int
 Key_List::strcspn (const char *s, const char *reject)
 {
@@ -184,6 +185,7 @@ Key_List::strcspn (const char *s, const char *reject)
 
   return count;
 }
+#endif
 
 /* Sets up the Return_Type, the Struct_Tag type and the Array_Type
    based upon various user Options. */
@@ -424,7 +426,8 @@ void
 Key_List::reorder (void)
 {
   T (Trace t ("Key_List::reorder");)
-  for (List_Node *ptr = head; ptr; ptr = ptr->next)
+  List_Node *ptr;
+  for (ptr = head; ptr; ptr = ptr->next)
     ptr->occurrence = get_occurrence (ptr);
   
   occurrence_sort = !(hash_sort = 0); /* Pretty gross, eh?! */
@@ -464,7 +467,8 @@ void
 Key_List::output_min_max ()
 {
   T (Trace t ("Key_List::output_min_max");)
-  for (List_Node *temp = head; temp->next; temp = temp->next)
+  List_Node *temp;
+  for (temp = head; temp->next; temp = temp->next)
     ;
 
   min_hash_value = head->hash_value;
@@ -696,7 +700,8 @@ Key_List::output_keyword_table (void)
   /* Skip over leading blank entries if there are no duplicates. */
 
   printf ("      ");
-  for (int column = 1; index < head->hash_value; index++, column++)
+  int column;
+  for (column = 1; index < head->hash_value; index++, column++)
     printf ("%s\"\",%s %s", l_brace, r_brace, column % 9 ? "" : "\n      ");      
   if (column % 10)
     printf ("\n");
@@ -946,7 +951,8 @@ Key_List::output_lookup_array (void)
                      dup_ptr - duplicates, dup_ptr->hash_value, dup_ptr->index, dup_ptr->count);
 
           /* Start searching for available space towards the right part of the lookup array. */
-          for (int i = dup_ptr->hash_value; i < max_hash_value; i++)
+	  int i;
+          for (i = dup_ptr->hash_value; i < max_hash_value; i++)
             if (lookup_array[i] == DEFAULT_VALUE && lookup_array[i + 1] == DEFAULT_VALUE)
               {
                 lookup_array[i] = -dup_ptr->index;
