@@ -68,7 +68,8 @@ void printBag(intBag& a)
   int maxprint = 20;
   cout << "[";
   int k = 0;
-  for (Pix i = a.first(); i != 0 && k < maxprint; a.next(i),++k) 
+  Pix i;
+  for (i = a.first(); i != 0 && k < maxprint; a.next(i),++k) 
     cout << a(i) << " ";
   if (i != 0) cout << "...]\n";
   else cout << "]\n";
@@ -79,7 +80,8 @@ void generictest(intBag& a, intBag& b, intBag& c)
 {
   c.clear();
   assert(c.empty());
-  for (Pix k = a.first(); k != 0; a.next(k)) c.add(a(k));
+  Pix k;
+  for (k = a.first(); k != 0; a.next(k)) c.add(a(k));
   for (k = a.first(); k != 0; a.next(k)) assert(c.contains(a(k)));
   c.del(a(a.first()));
   Pix i = a.first();
@@ -120,7 +122,7 @@ void XPtest()
   cout << "b: "; printBag(b);
   cout << "c: "; printBag(c);
   cout << "d: "; printBag(d);
-  for (j = 1; j <= SIZE; ++j) assert(d.nof(j) == 2);
+  for (int j = 1; j <= SIZE; ++j) assert(d.nof(j) == 2);
   d.del(1);
   assert(d.nof(1) == 1);
   d.del(1);
@@ -133,17 +135,17 @@ void XPtest()
   c.clear();
   assert(c.empty());
   for (Pix k = a.first(); k != 0; a.next(k)) c.add(a(k));
-  for (k = a.first(); k != 0; a.next(k)) assert(c.contains(a(k)));
+  for (Pix k = a.first(); k != 0; a.next(k)) assert(c.contains(a(k)));
   c.del(a(a.first()));
   Pix i = a.first();
   assert(!c.contains(a(i)));
   for (a.next(i); i != 0; a.next(i)) assert(c.contains(a(i)));
   c.add(a(a.first()));
   for (i = a.first(); i != 0; a.next(i)) assert(c.contains(a(i)));
-  for (k = b.first(); k != 0; b.next(k)) c.add(b(k));
+  for (Pix k = b.first(); k != 0; b.next(k)) c.add(b(k));
   for (i = b.first(); i != 0; b.next(i)) assert(c.contains(b(i)));
   for (i = a.first(); i != 0; a.next(i)) assert(c.contains(a(i)));
-  for (k = a.first(); k != 0; a.next(k)) c.remove(a(k));
+  for (Pix k = a.first(); k != 0; a.next(k)) c.remove(a(k));
   for (i = a.first(); i != 0; a.next(i)) assert(!c.contains(a(i)));
   for (i = b.first(); i != 0; b.next(i)) c.del(b(i));
   assert(c.empty());
@@ -162,7 +164,8 @@ void SLtest()
   intSLBag a;
   add(nums, a);
   assert(a.length() == SIZE);
-  for (int j = 1; j <= SIZE; ++j) assert(a.contains(j));
+  int j;
+  for (j = 1; j <= SIZE; ++j) assert(a.contains(j));
   intSLBag b;
   add(odds, b);
   assert(b.length() == SIZE);
@@ -189,17 +192,17 @@ void SLtest()
   c.clear();
   assert(c.empty());
   for (Pix k = a.first(); k != 0; a.next(k)) c.add(a(k));
-  for (k = a.first(); k != 0; a.next(k)) assert(c.contains(a(k)));
+  for (Pix k = a.first(); k != 0; a.next(k)) assert(c.contains(a(k)));
   c.del(a(a.first()));
   Pix i = a.first();
   assert(!c.contains(a(i)));
   for (a.next(i); i != 0; a.next(i)) assert(c.contains(a(i)));
   c.add(a(a.first()));
   for (i = a.first(); i != 0; a.next(i)) assert(c.contains(a(i)));
-  for (k = b.first(); k != 0; b.next(k)) c.add(b(k));
+  for (Pix k = b.first(); k != 0; b.next(k)) c.add(b(k));
   for (i = b.first(); i != 0; b.next(i)) assert(c.contains(b(i)));
   for (i = a.first(); i != 0; a.next(i)) assert(c.contains(a(i)));
-  for (k = a.first(); k != 0; a.next(k)) c.remove(a(k));
+  for (Pix k = a.first(); k != 0; a.next(k)) c.remove(a(k));
   for (i = a.first(); i != 0; a.next(i)) assert(!c.contains(a(i)));
   for (i = b.first(); i != 0; b.next(i)) c.del(b(i));
   assert(c.empty());
@@ -218,7 +221,8 @@ void VHtest()
   intVHBag a(SIZE);
   add(nums, a);
   assert(a.length() == SIZE);
-  for (int j = 1; j <= SIZE; ++j) assert(a.contains(j));
+  int j;
+  for (j = 1; j <= SIZE; ++j) assert(a.contains(j));
   intVHBag b(SIZE);
   add(odds, b);
   assert(b.length() == SIZE);
@@ -245,17 +249,17 @@ void VHtest()
   c.clear();
   assert(c.empty());
   for (Pix k = a.first(); k != 0; a.next(k)) c.add(a(k));
-  for (k = a.first(); k != 0; a.next(k)) assert(c.contains(a(k)));
+  for (Pix k = a.first(); k != 0; a.next(k)) assert(c.contains(a(k)));
   c.del(a(a.first()));
   Pix i = a.first();
   assert(!c.contains(a(i)));
   for (a.next(i); i != 0; a.next(i)) assert(c.contains(a(i)));
   c.add(a(a.first()));
   for (i = a.first(); i != 0; a.next(i)) assert(c.contains(a(i)));
-  for (k = b.first(); k != 0; b.next(k)) c.add(b(k));
+  for (Pix k = b.first(); k != 0; b.next(k)) c.add(b(k));
   for (i = b.first(); i != 0; b.next(i)) assert(c.contains(b(i)));
   for (i = a.first(); i != 0; a.next(i)) assert(c.contains(a(i)));
-  for (k = a.first(); k != 0; a.next(k)) c.remove(a(k));
+  for (Pix k = a.first(); k != 0; a.next(k)) c.remove(a(k));
   for (i = a.first(); i != 0; a.next(i)) assert(!c.contains(a(i)));
   for (i = b.first(); i != 0; b.next(i)) c.del(b(i));
   assert(c.empty());
@@ -273,7 +277,8 @@ void CHtest()
   intCHBag a(SIZE);
   add(nums, a);
   assert(a.length() == SIZE);
-  for (int j = 1; j <= SIZE; ++j) assert(a.contains(j));
+  int j;
+  for (j = 1; j <= SIZE; ++j) assert(a.contains(j));
   intCHBag b(SIZE);
   add(odds, b);
   assert(b.length() == SIZE);
@@ -300,17 +305,17 @@ void CHtest()
   c.clear();
   assert(c.empty());
   for (Pix k = a.first(); k != 0; a.next(k)) c.add(a(k));
-  for (k = a.first(); k != 0; a.next(k)) assert(c.contains(a(k)));
+  for (Pix k = a.first(); k != 0; a.next(k)) assert(c.contains(a(k)));
   c.del(a(a.first()));
   Pix i = a.first();
   assert(!c.contains(a(i)));
   for (a.next(i); i != 0; a.next(i)) assert(c.contains(a(i)));
   c.add(a(a.first()));
   for (i = a.first(); i != 0; a.next(i)) assert(c.contains(a(i)));
-  for (k = b.first(); k != 0; b.next(k)) c.add(b(k));
+  for (Pix k = b.first(); k != 0; b.next(k)) c.add(b(k));
   for (i = b.first(); i != 0; b.next(i)) assert(c.contains(b(i)));
   for (i = a.first(); i != 0; a.next(i)) assert(c.contains(a(i)));
-  for (k = a.first(); k != 0; a.next(k)) c.remove(a(k));
+  for (Pix k = a.first(); k != 0; a.next(k)) c.remove(a(k));
   for (i = a.first(); i != 0; a.next(i)) assert(!c.contains(a(i)));
   for (i = b.first(); i != 0; b.next(i)) c.del(b(i));
   assert(c.empty());
@@ -328,7 +333,8 @@ void OXPtest()
   intOXPBag a(SIZE);
   add(nums, a);
   assert(a.length() == SIZE);
-  for (int j = 1; j <= SIZE; ++j) assert(a.contains(j));
+  int j;
+  for (j = 1; j <= SIZE; ++j) assert(a.contains(j));
   intOXPBag b(SIZE);
   add(odds, b);
   assert(b.length() == SIZE);
@@ -355,17 +361,17 @@ void OXPtest()
   c.clear();
   assert(c.empty());
   for (Pix k = a.first(); k != 0; a.next(k)) c.add(a(k));
-  for (k = a.first(); k != 0; a.next(k)) assert(c.contains(a(k)));
+  for (Pix k = a.first(); k != 0; a.next(k)) assert(c.contains(a(k)));
   c.del(a(a.first()));
   Pix i = a.first();
   assert(!c.contains(a(i)));
   for (a.next(i); i != 0; a.next(i)) assert(c.contains(a(i)));
   c.add(a(a.first()));
   for (i = a.first(); i != 0; a.next(i)) assert(c.contains(a(i)));
-  for (k = b.first(); k != 0; b.next(k)) c.add(b(k));
+  for (Pix k = b.first(); k != 0; b.next(k)) c.add(b(k));
   for (i = b.first(); i != 0; b.next(i)) assert(c.contains(b(i)));
   for (i = a.first(); i != 0; a.next(i)) assert(c.contains(a(i)));
-  for (k = a.first(); k != 0; a.next(k)) c.remove(a(k));
+  for (Pix k = a.first(); k != 0; a.next(k)) c.remove(a(k));
   for (i = a.first(); i != 0; a.next(i)) assert(!c.contains(a(i)));
   for (i = b.first(); i != 0; b.next(i)) c.del(b(i));
   assert(c.empty());
@@ -384,7 +390,8 @@ void OSLtest()
   intOSLBag a;
   add(nums, a);
   assert(a.length() == SIZE);
-  for (int j = 1; j <= SIZE; ++j) assert(a.contains(j));
+  int j;
+  for (j = 1; j <= SIZE; ++j) assert(a.contains(j));
   intOSLBag b;
   add(odds, b);
   assert(b.length() == SIZE);
@@ -411,17 +418,17 @@ void OSLtest()
   c.clear();
   assert(c.empty());
   for (Pix k = a.first(); k != 0; a.next(k)) c.add(a(k));
-  for (k = a.first(); k != 0; a.next(k)) assert(c.contains(a(k)));
+  for (Pix k = a.first(); k != 0; a.next(k)) assert(c.contains(a(k)));
   c.del(a(a.first()));
   Pix i = a.first();
   assert(!c.contains(a(i)));
   for (a.next(i); i != 0; a.next(i)) assert(c.contains(a(i)));
   c.add(a(a.first()));
   for (i = a.first(); i != 0; a.next(i)) assert(c.contains(a(i)));
-  for (k = b.first(); k != 0; b.next(k)) c.add(b(k));
+  for (Pix k = b.first(); k != 0; b.next(k)) c.add(b(k));
   for (i = b.first(); i != 0; b.next(i)) assert(c.contains(b(i)));
   for (i = a.first(); i != 0; a.next(i)) assert(c.contains(a(i)));
-  for (k = a.first(); k != 0; a.next(k)) c.remove(a(k));
+  for (Pix k = a.first(); k != 0; a.next(k)) c.remove(a(k));
   for (i = a.first(); i != 0; a.next(i)) assert(!c.contains(a(i)));
   for (i = b.first(); i != 0; b.next(i)) c.del(b(i));
   assert(c.empty());
@@ -439,7 +446,8 @@ void Splaytest()
   intSplayBag a;
   add(nums, a);
   assert(a.length() == SIZE);
-  for (int j = 1; j <= SIZE; ++j) assert(a.contains(j));
+  int j;
+  for (j = 1; j <= SIZE; ++j) assert(a.contains(j));
   intSplayBag b;
   add(odds, b);
   assert(b.length() == SIZE);
@@ -466,17 +474,17 @@ void Splaytest()
   c.clear();
   assert(c.empty());
   for (Pix k = a.first(); k != 0; a.next(k)) c.add(a(k));
-  for (k = a.first(); k != 0; a.next(k)) assert(c.contains(a(k)));
+  for (Pix k = a.first(); k != 0; a.next(k)) assert(c.contains(a(k)));
   c.del(a(a.first()));
   Pix i = a.first();
   assert(!c.contains(a(i)));
   for (a.next(i); i != 0; a.next(i)) assert(c.contains(a(i)));
   c.add(a(a.first()));
   for (i = a.first(); i != 0; a.next(i)) assert(c.contains(a(i)));
-  for (k = b.first(); k != 0; b.next(k)) c.add(b(k));
+  for (Pix k = b.first(); k != 0; b.next(k)) c.add(b(k));
   for (i = b.first(); i != 0; b.next(i)) assert(c.contains(b(i)));
   for (i = a.first(); i != 0; a.next(i)) assert(c.contains(a(i)));
-  for (k = a.first(); k != 0; a.next(k)) c.remove(a(k));
+  for (Pix k = a.first(); k != 0; a.next(k)) c.remove(a(k));
   for (i = a.first(); i != 0; a.next(i)) assert(!c.contains(a(i)));
   for (i = b.first(); i != 0; b.next(i)) c.del(b(i));
   assert(c.empty());
